// Using interrupt with Pinguino32
// Jean-Pierre MANDON 2011

#include <interrupt.c>

unsigned int counter=0;


void ISR_wrapper_vector_4(void) __attribute__ ((section (".vector_4")));
// Put the ISR_wrapper in the good place

void ISR_wrapper_vector_4(void)
{
	Tmr1Interrupt();
}
// ISR_wrapper will call the Tmr1Interrupt()

void Tmr1Interrupt(void) __attribute__ ((interrupt));
// Tmr1Interrupt is declared as an interrupt routine

// define here the code to execute when an interrupt occure
void Tmr1Interrupt(void)
{
	if (IFS0bits.T1IF) {	// Timer Interrupt flag
		TMR1=0;			// reset the timer register
		IFS0CLR=0x10;		// Clear the timer interrupt flag
		counter++;		// increment the counter
	}
}

// configure timer 1
void init_timer1(void)
{
	IntConfigureSystem(INT_SYSTEM_CONFIG_MULT_VECTOR);	// interrupt mode (interrupt.c)
	T1CON=0;		// reset timer 1 configuration
	TMR1=0;			// reset timer 1 counter register
	PR1=0x9999;		// define the preload register
	IPC1SET=0x7;		// select interrupt priority and sub-priority
	IFS0CLR=0x10;		// clear interrupt flag
	IEC0SET=0x10;		// enable timer 1 interrupt
	T1CONSET=0x8010;	// start timer 1 and set prescaler
}

void setup()
{
	pinmode(13, OUTPUT);
	init_timer1();
}

void loop()
{
  static int cnt=0;
  cnt++;
  if(cnt >= 500) {
  	CDC.printf("%d\n\r",counter);	// counter is incremented at each timer 1 overflow
    toggle(13);
    cnt=0;
  }    
	delay(1);
}
